Back class

Constructors

Back({ButtonStyle? style, required Widget child, Duration? animationDuration = const Duration(seconds: 1), Curve? curve = Curves.easeInOut})
const

Properties

animationDuration → Duration?
The animation lasts for the given duration and follows the given curve. The returned Future resolves when the animation completes.
final
child → Widget
Back button's child widget.
final
curve → Curve?
A collection of common animation easing curves.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ButtonStyle?
Many of the ButtonStyle properties are MaterialStateProperty objects which resolve to different values depending on the button's state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited