DotIndicator class

Constructors

DotIndicator({double? size = 10, Color? selectedColor = Colors.blue, Color? unselectedColor})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
The selected color of the dot.
final
size → double?
The size of the dot.
final
unselectedColor → Color?
The unselected color of the dot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited